from django_databrowse.sites import (DatabrowsePlugin, ModelDatabrowse,
                                     DefaultModelDatabrowse, site)

__ALL__ = [DatabrowsePlugin, ModelDatabrowse,
           DefaultModelDatabrowse, site]

__version__ = (1, 2)
