{% extends "databrowse/base_site.html" %}
{% load i18n %}

{% block title %}{{ model.verbose_name_plural|capfirst }} {% trans "by" %} {{ field.field.verbose_name }}: {{ value }}{% endblock %}

{% block content %}

<div id="breadcrumbs"><a href="{{ root_url }}">{% trans "Home" %}</a> / <a href="{{ model.url }}">{{ model.verbose_name_plural|capfirst }}</a> / <a href="{{ field.url }}">{% trans "By" %} {{ field.field.verbose_name }}</a> / {{ value }}</div>

<h1>{{ model.verbose_name_plural|capfirst }} {% trans "by" %} {{ field.field.verbose_name }}: {{ value }}</h1>

<ul class="objectlist">
{% for object in object_list %}
<li class="{% cycle 'odd' 'even' %}"><a href="{{ object.url }}">{{ object }}</a></li>
{% endfor %}
</ul>

{% include "databrowse/include/pagination.html" %}

{% endblock %}
