{% extends "databrowse/base_site.html" %}
{% load i18n %}

{% block title %}{% blocktrans with verbose_name=model.verbose_name_plural %}Browsable fields in {{ verbose_name }}{% endblocktrans %}{% endblock %}
{% block content %}

<div id="breadcrumbs"><a href="{{ root_url }}">{% trans "Home" %}</a> / <a href="{{ model.url }}">{{ model.verbose_name_plural|capfirst }}</a> / {% trans "Fields" %}</div>

<h1>{% blocktrans with verbose_name=model.verbose_name_plural %}Browsable fields in {{ verbose_name }}{% endblocktrans %}</h1>

<ul class="objectlist">
{% for field in field_list %}
<li class="{% cycle 'odd' 'even' %}"><a href="{{ field.name }}/">{{ model.verbose_name_plural|capfirst }} {% trans "by" %} {{ field.verbose_name }}</a></li>
{% endfor %}
</ul>

{% endblock %}
